;;; iso-syntax.el --- set up case-conversion and syntax tables for ISO 8859/1

;; Copyright (C) 1988 Free Software Foundation, Inc.
;; Copyright (C) 1995 ϴϸ 

;; Author: Howard Gayle
;; Maintainer: FSF
;; Keywords: i18n

;; This file is part of GNU Emacs.

;; GNU Emacs is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; GNU Emacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Commentary:

;; Written by Howard Gayle.  See case-table.el for details.

;;; Change
;; 1995/09/17 changed by fpf545, for hanemacs
;; 160 - 255 ڵ带 word  ٲٰ, case .

;;; Code:

(require 'case-table)

(let ((downcase (standard-case-table)))
  (set-case-syntax 160 "w" downcase)	; NBSP (no-break space)
  (set-case-syntax 161 "w" downcase)	; inverted exclamation mark
  (set-case-syntax 162 "w" downcase)	; cent sign
  (set-case-syntax 163 "w" downcase)	; pound sign
  (set-case-syntax 164 "w" downcase)	; general currency sign
  (set-case-syntax 165 "w" downcase)	; yen sign
  (set-case-syntax 166 "w" downcase)	; broken vertical line
  (set-case-syntax 167 "w" downcase)	; section sign
  (set-case-syntax 168 "w" downcase)	; diaeresis
  (set-case-syntax 169 "w" downcase)	; copyright sign
  (set-case-syntax 170 "w" downcase)	; ordinal indicator, feminine
;  (set-case-syntax-delims 171 187 downcase) ; angle quotation marks
  (set-case-syntax 171 "w" downcase)    ; angle quotation marks
  (set-case-syntax 172 "w" downcase)	; not sign
  (set-case-syntax 173 "w" downcase)	; soft hyphen
  (set-case-syntax 174 "w" downcase)	; registered sign
  (set-case-syntax 175 "w" downcase)	; macron
  (set-case-syntax 176 "w" downcase)	; degree sign
  (set-case-syntax 177 "w" downcase)	; plus or minus sign
  (set-case-syntax 178 "w" downcase)	; superscript two
  (set-case-syntax 179 "w" downcase)	; superscript three
  (set-case-syntax 180 "w" downcase)	; acute accent
  (set-case-syntax 181 "w" downcase)	; micro sign
  (set-case-syntax 182 "w" downcase)	; pilcrow
  (set-case-syntax 183 "w" downcase)	; middle dot
  (set-case-syntax 184 "w" downcase)	; cedilla
  (set-case-syntax 185 "w" downcase)	; superscript one
  (set-case-syntax 186 "w" downcase)	; ordinal indicator, masculine
  (set-case-syntax 187 "w" downcase)    ; angle quotation marks
  ;;    	       	      187          ; See 171 above.
  (set-case-syntax 188 "w" downcase)	; fraction one-quarter
  (set-case-syntax 189 "w" downcase)	; fraction one-half
  (set-case-syntax 190 "w" downcase)	; fraction three-quarters
  (set-case-syntax 191 "w" downcase)	; inverted question mark
  (set-case-syntax 192 "w" downcase) ; A with grave accent
  (set-case-syntax 193 "w" downcase) ; A with acute accent
  (set-case-syntax 194 "w" downcase) ; A with circumflex accent
  (set-case-syntax 195 "w" downcase) ; A with tilde
  (set-case-syntax 196 "w" downcase) ; A with diaeresis or umlaut mark
  (set-case-syntax 197 "w" downcase) ; A with ring
  (set-case-syntax 198 "w" downcase) ; AE diphthong
  (set-case-syntax 199 "w" downcase) ; C with cedilla
  (set-case-syntax 200 "w" downcase) ; E with grave accent
  (set-case-syntax 201 "w" downcase) ; E with acute accent
  (set-case-syntax 202 "w" downcase) ; E with circumflex accent
  (set-case-syntax 203 "w" downcase) ; E with diaeresis or umlaut mark
  (set-case-syntax 204 "w" downcase) ; I with grave accent
  (set-case-syntax 205 "w" downcase) ; I with acute accent
  (set-case-syntax 206 "w" downcase) ; I with circumflex accent
  (set-case-syntax 207 "w" downcase) ; I with diaeresis or umlaut mark
  (set-case-syntax 208 "w" downcase) ; D with stroke, Icelandic eth
  (set-case-syntax 209 "w" downcase) ; N with tilde
  (set-case-syntax 210 "w" downcase) ; O with grave accent
  (set-case-syntax 211 "w" downcase) ; O with acute accent
  (set-case-syntax 212 "w" downcase) ; O with circumflex accent
  (set-case-syntax 213 "w" downcase) ; O with tilde
  (set-case-syntax 214 "w" downcase) ; O with diaeresis or umlaut mark
  (set-case-syntax 215 "w" downcase)	; multiplication sign
  (set-case-syntax 216 "w" downcase) ; O with slash
  (set-case-syntax 217 "w" downcase) ; U with grave accent
  (set-case-syntax 218 "w" downcase) ; U with acute accent
  (set-case-syntax 219 "w" downcase) ; U with circumflex accent
  (set-case-syntax 220 "w" downcase) ; U with diaeresis or umlaut mark
  (set-case-syntax 221 "w" downcase) ; Y with acute accent
  (set-case-syntax 222 "w" downcase) ; thorn, Icelandic
  (set-case-syntax 223 "w" downcase)	; small sharp s, German
  (set-case-syntax 224 "w" downcase) ; A with grave accent
  (set-case-syntax 225 "w" downcase) ; A with acute accent
  (set-case-syntax 226 "w" downcase) ; A with circumflex accent
  (set-case-syntax 227 "w" downcase) ; A with tilde
  (set-case-syntax 228 "w" downcase) ; A with diaeresis or umlaut mark
  (set-case-syntax 229 "w" downcase) ; A with ring
  (set-case-syntax 230 "w" downcase) ; AE diphthong
  (set-case-syntax 231 "w" downcase) ; C with cedilla
  (set-case-syntax 232 "w" downcase) ; E with grave accent
  (set-case-syntax 233 "w" downcase) ; E with acute accent
  (set-case-syntax 234 "w" downcase) ; E with circumflex accent
  (set-case-syntax 235 "w" downcase) ; E with diaeresis or umlaut mark
  (set-case-syntax 236 "w" downcase) ; I with grave accent
  (set-case-syntax 237 "w" downcase) ; I with acute accent
  (set-case-syntax 238 "w" downcase) ; I with circumflex accent
  (set-case-syntax 239 "w" downcase) ; I with diaeresis or umlaut mark
  (set-case-syntax 240 "w" downcase) ; D with stroke, Icelandic eth
  (set-case-syntax 241 "w" downcase) ; N with tilde
  (set-case-syntax 242 "w" downcase) ; O with grave accent
  (set-case-syntax 243 "w" downcase) ; O with acute accent
  (set-case-syntax 244 "w" downcase) ; O with circumflex accent
  (set-case-syntax 245 "w" downcase) ; O with tilde
  (set-case-syntax 246 "w" downcase) ; O with diaeresis or umlaut mark

  (set-case-syntax 247 "w" downcase)	; division sign
  (set-case-syntax 248 "w" downcase)
  (set-case-syntax 249 "w" downcase)
  (set-case-syntax 250 "w" downcase)
  (set-case-syntax 251 "w" downcase)
  (set-case-syntax 252 "w" downcase)
  (set-case-syntax 253 "w" downcase)
  (set-case-syntax 254 "w" downcase)
  (set-case-syntax 255 "w" downcase)	; small y with diaeresis or umlaut mark
)

(provide 'iso-syntax)

;;; iso-syntax.el ends here
